@@ -1,4 +1,5 @@
 # Django
+from django.db.models import ManyToManyField
 from django.db import connection
 from django.apps import apps
 
@@ -44,8 +45,18 @@ def refresh_models(models):
 
 
 def model_sync(data, model):
-    fields = [field.name for field in model._meta.fields]
+    fields = [field.get_attname() for field in model._meta.fields]
+    m2m_fields = [
+        field.get_attname() for field in model._meta.get_fields()
+        if field.__class__ is ManyToManyField
+    ]
 
     for item in data:
         defaults = pick(fields, item)
+
         model.objects.update_or_create(id=item['id'], defaults=defaults)
+        if m2m_fields:
+            instance = model.objects.get(id=item['id'])
+
+            for field in m2m_fields:
+                getattr(instance, field).set(item[field])
